﻿using Microsoft.Extensions.Logging;
using Newtonsoft.Json.Linq;

namespace SteamGameTimeTrack;

public class Net
{
    private readonly ILogger _logger;
    private readonly string _apiToken;
    private DateTime lastRequest = DateTime.UtcNow;
    private readonly TimeSpan _minTimeBetweenRequests = TimeSpan.FromMilliseconds(10);

    public Net(ILogger logger, string apiToken)
    {
        _logger = logger;
        _apiToken = apiToken;
    }

    internal HttpResponseMessage MakeRequest(string uri, string? requestId = null)
    {
        if (requestId is null)
        {
            requestId = RandomString(4);
            this._logger.LogDebug($"RequestId: {requestId} for URI {uri}");
        }
        HttpClient client = new();
        uri = uri.Contains("format=json") ? uri : $"{uri}&format=json";
        uri = uri.Contains("key=") ? uri : $"{uri}&key={_apiToken}";
        HttpRequestMessage request = new (HttpMethod.Get, uri);
        TimeSpan wait = this.lastRequest.Add(_minTimeBetweenRequests).Subtract(DateTime.UtcNow);
        if (wait > TimeSpan.Zero)
        {
            this._logger.LogDebug($"Waiting {wait:s\\.fffff's'} before requesting {requestId}...");
            Thread.Sleep(wait);
        }else
            this._logger.LogDebug($"Requesting {requestId}...");
        HttpResponseMessage response = client.Send(request, HttpCompletionOption.ResponseContentRead);
        this.lastRequest = DateTime.UtcNow;
        this._logger.LogDebug($"Request {requestId} -> {response.StatusCode}");
        return response;
    }

    internal JObject? MakeRequestGetJObject(string uri, string? requestId = null)
    {
        if (requestId is null)
        {
            requestId = RandomString(4);
            this._logger.LogDebug($"RequestId: {requestId} for URI {uri}");
        }
        HttpResponseMessage response = MakeRequest(uri, requestId);
        if (!response.IsSuccessStatusCode)
            return null;
        this._logger.LogDebug($"Parsing JObject for {requestId}...");
        return JObject.Parse(response.Content.ReadAsStringAsync().Result);
    }
    
    private static string RandomString(int length)
    {
        const string chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
        return new string(Enumerable.Repeat(chars, length)
            .Select(s => s[Random.Shared.Next(s.Length)]).ToArray());
    }
}