﻿// See https://aka.ms/new-console-template for more information

using Microsoft.Extensions.Logging;
using Newtonsoft.Json;
using SteamGameTimeTrack;

Config config;

if (File.Exists("config.json"))
    config = JsonConvert.DeserializeObject<Config>(File.ReadAllText("config.json"));
else
{
    string? steamid;
    do
    {
        Console.Clear();
        Console.WriteLine("SteamId:");
        steamid = Console.ReadLine();
    } while (steamid is null || steamid.Length < 1);
    
    string? apiKey;
    do
    {
        Console.Clear();
        Console.WriteLine("API-Key:");
        apiKey = Console.ReadLine();
    } while (apiKey is null || apiKey.Length < 1);

    LogLevel logLevel;
    string[] levels = Enum.GetNames<LogLevel>();
    do
    {
        Console.Clear();
        for (int i = 0; i < levels.Length; i++)
            Console.WriteLine($"{i}) {levels[i]}");
    } while (!int.TryParse(Console.ReadKey().KeyChar.ToString(), out int selectedLevel) || selectedLevel < 0 ||
             selectedLevel >= levels.Length || !Enum.TryParse<LogLevel>(levels[selectedLevel], out logLevel));
    
    Console.Clear();
    Console.WriteLine("Track friends? (y/n)");
    bool trackFriends = Console.ReadKey(true).Key == ConsoleKey.Y;

    int port;
    do
    {
        Console.Clear();
        Console.WriteLine("API-Port:");
    } while (!int.TryParse(Console.ReadLine(), out port) || port < 1 || port > 65535);

    config = new()
    {
        SteamId = steamid,
        ApiToken = apiKey,
        LogLevel = logLevel,
        TrackFriends = trackFriends,
        ApiPort = port
    };
}



Tracker t = new (config);
while(Console.ReadKey(true).Key != ConsoleKey.Q)
    Console.WriteLine("Press q to quit.");
t.Dispose();    